@@ -89,6 +89,72 @@ ICESSL_API TrustError getTrustError(const IceSSL::ConnectionInfoPtr&);
 ICESSL_API std::string getTrustErrorDescription(TrustError);
 ICESSL_API std::string getHost(const IceSSL::ConnectionInfoPtr&);
 
+/**
+ * The key usage "digitalSignature" bit is set
+ */
+const unsigned int KEY_USAGE_DIGITAL_SIGNATURE = 1u << 0;
+/**
+ * The key usage "nonRepudiation" bit is set
+ */
+const unsigned int KEY_USAGE_NON_REPUDIATION = 1u << 1;
+/**
+ * The key usage "keyEncipherment" bit is set
+ */
+const unsigned int KEY_USAGE_KEY_ENCIPHERMENT = 1u << 2;
+/**
+ * The key usage "dataEncipherment" bit is set
+ */
+const unsigned int KEY_USAGE_DATA_ENCIPHERMENT = 1u << 3;
+/**
+ * The key usage "keyAgreement" bit is set
+ */
+const unsigned int KEY_USAGE_KEY_AGREEMENT = 1u << 4;
+/**
+ * The key usage "keyCertSign" bit is set
+ */
+const unsigned int KEY_USAGE_KEY_CERT_SIGN = 1u << 5;
+/**
+ * The key usage "cRLSign" bit is set
+ */
+const unsigned int KEY_USAGE_CRL_SIGN = 1u << 6;
+/**
+ * The key usage "encipherOnly" bit is set
+ */
+const unsigned int KEY_USAGE_ENCIPHER_ONLY = 1u << 7;
+/**
+ * The key usage "decipherOnly" bit is set
+ */
+const unsigned int KEY_USAGE_DECIPHER_ONLY = 1u << 8;
+
+/**
+ * The extended key usage "anyKeyUsage" bit is set
+ */
+const unsigned int EXTENDED_KEY_USAGE_ANY_KEY_USAGE = 1u << 0;
+/**
+ * The extended key usage "serverAuth" bit is set
+ */
+const unsigned int EXTENDED_KEY_USAGE_SERVER_AUTH = 1u << 1;
+/**
+ * The extended key usage "clientAuth" bit is set
+ */
+const unsigned int EXTENDED_KEY_USAGE_CLIENT_AUTH = 1u << 2;
+/**
+ * The extended key usage "codeSigning" bit is set
+ */
+const unsigned int EXTENDED_KEY_USAGE_CODE_SIGNING = 1u << 3;
+/**
+ * The extended key usage "emailProtection" bit is set
+ */
+const unsigned int EXTENDED_KEY_USAGE_EMAIL_PROTECTION = 1u << 4;
+/**
+ * The extended key usage "timeStamping" bit is set
+ */
+const unsigned int EXTENDED_KEY_USAGE_TIME_STAMPING = 1u << 5;
+/**
+ * The extended key usage "OCSPSigning" bit is set
+ */
+const unsigned int EXTENDED_KEY_USAGE_OCSP_SIGNING = 1u << 6;
+
 /**
  * Thrown if the certificate cannot be read.
  * \headerfile IceSSL/IceSSL.h
@@ -401,6 +467,24 @@ public:
     virtual bool checkValidity(const IceUtil::Time& t) const = 0;
 #endif
 
+    /**
+     * Returns the value of the key usage extension. The flags <b>KEY_USAGE_DIGITAL_SIGNATURE</b>,
+     * <b>KEY_USAGE_NON_REPUDIATION</b>, <b>KEY_USAGE_KEY_ENCIPHERMENT</b>, <b>KEY_USAGE_DATA_ENCIPHERMENT</b>
+     * <b>KEY_USAGE_KEY_AGREEMENT</b>, <b>KEY_USAGE_KEY_CERT_SIGN</b>, <b>KEY_USAGE_CRL_SIGN</b>,
+     * <b>KEY_USAGE_ENCIPHER_ONLY</b> and <b>KEY_USAGE_DECIPHER_ONLY</b> can be used to check what
+     * key usage bits are set.
+     */
+    unsigned int getKeyUsage() const;
+
+    /**
+     * Returns the value of the extended key usage extension. The flags <b>EXTENDED_KEY_USAGE_ANY_KEY_USAGE</b>,
+     * <b>EXTENDED_KEY_USAGE_SERVER_AUTH</b>, <b>EXTENDED_KEY_USAGE_CLIENT_AUTH</b>,
+     * <b>EXTENDED_KEY_USAGE_CODE_SIGNING</b>, <b>EXTENDED_KEY_USAGE_EMAIL_PROTECTION</b>,
+     * <b>EXTENDED_KEY_USAGE_TIME_STAMPING</b> and <b>EXTENDED_KEY_USAGE_OCSP_SIGNING</b> can be used to check what
+     * extended key usage bits are set.
+     */
+    unsigned int getExtendedKeyUsage() const;
+
     /**
      * Obtains the not-after validity time.
      * @return The time after which this certificate is invalid.
